import { Api } from './api';
import { Meta } from './core';
import { PromiseProgress, TypedEmitter, TypedEvents } from '@ztimson/utils';
export type Document<T> = Meta & T;
export type RawQuery = {
    operand: 'delete' | 'deleteOne' | 'find' | 'findOne' | 'insert' | 'replaceOne' | 'update' | 'updateOne';
    filter?: any;
    data?: any;
    options?: any;
    count?: boolean;
};
export type Schema = Meta & {
    /** Collection path/name */
    path: string;
    /** Description of data */
    description?: string;
    /** Last index number */
    autoIncrement?: number;
    /** Hide columns */
    hide?: string[];
    /** Lock collection from changes */
    lock?: boolean;
    /** Allow updates to create row if missing */
    upsert?: boolean;
    /** Defined fields */
    fields?: SchemaField[];
};
export type SchemaField = {
    /** Display label */
    label: string;
    /** Property key */
    property: string;
    /** Variable type */
    type: string;
    /** Display formating */
    format: string;
    /** Extra settings for formatting */
    formatArgs: any;
    /** Default value */
    default: any;
    /** Allow empty value */
    nullable: boolean;
};
/**
 * Recursive type for defining data schema
 */
export type SchemaNode = Schema & {
    name: string;
    children: SchemaNode[];
};
export type DataEvents = TypedEvents & {
    create: (collection: string, document: any) => any;
    read: (collection: string, documents: any | any[]) => any;
    update: (collection: string, document: any) => any;
    delete: (collection: string, document: number) => any;
    raw: (collection: string, query: RawQuery, response: any) => any;
};
export declare class Data extends TypedEmitter<DataEvents> {
    private readonly api;
    constructor(api: Api | string);
    create<T>(collection: string, document: Document<T>): Promise<Document<T>>;
    read<T extends Meta>(collection: string): Promise<T[]>;
    read<T extends Meta>(collection: string, id: number): Promise<T>;
    update<T>(collection: string, document: Document<T>, append?: boolean): Promise<Document<T>>;
    delete(collection: string, id: number): Promise<void>;
    raw<T>(collection: string, query: RawQuery): Promise<Document<T>>;
    deleteSchema(collection: string): PromiseProgress<void>;
    getSchema(tree?: false): Promise<string[]>;
    getSchema(tree?: boolean): Promise<SchemaNode[]>;
    getSchema(path?: string): Promise<Schema>;
    setSchema(schema: Partial<Schema> & {
        path: string;
    }): PromiseProgress<Schema>;
}
//# sourceMappingURL=data.d.ts.map